@@ -1,5 +1,5 @@
 #'@name k.read
-#'@aliases 
+#'@aliases
 #'k.read
 #'k.read.soloviev
 #'k.cole
@@ -8,7 +8,7 @@
 #'k.vachon
 #'k.heiskanen
 #'@title Returns a timeseries of gas exchange velocity
-#'@description 
+#'@description
 #'Returns the gas exchange velocity based on the chosen model in units of m/day
 #'@usage
 #'k.cole(ts.data)
@@ -33,8 +33,8 @@
 #'@param lake.area Lake area, m^2
 #'@param params Only for \link{k.vachon.base} and \link{k.macIntyre}. See details.
 #'
-#'@details Can change default parameters of MacIntyre and Vachon models. Default for Vachon is 
-#'c(2.51,1.48,0.39). Default for MacIntyre is c(1.2,0.4872,1.4784). Heiskanen 2014 uses MacIntyre 
+#'@details Can change default parameters of MacIntyre and Vachon models. Default for Vachon is
+#'c(2.51,1.48,0.39). Default for MacIntyre is c(1.2,0.4872,1.4784). Heiskanen 2014 uses MacIntyre
 #'model with c(0.5,0.77,0.3) and z.aml constant at 0.15.
 #'
 #'@return Returns a data.frame with a datetime column and a k600 column. k600 is in units of meters per day (m/d).
@@ -43,22 +43,22 @@
 #'@keywords methods math
 #'
 #'@references
-#'Cole, J., J. Nina, and F. Caraco. \emph{Atmospheric exchange of carbon dioxide 
-#'in a low-wind oligotrophic lake measured by the addition of SF~ 6}. 
+#'Cole, J., J. Nina, and F. Caraco. \emph{Atmospheric exchange of carbon dioxide
+#'in a low-wind oligotrophic lake measured by the addition of SF~ 6}.
 #'Limnology and Oceanography 43 (1998): 647-656.
 #'
-#'MacIntyre, Sally, Anders Jonsson, Mats Jansson, Jan Aberg, Damon E. Turney, 
-#'and Scott D. Miller. \emph{Buoyancy flux, turbulence, and the gas transfer 
+#'MacIntyre, Sally, Anders Jonsson, Mats Jansson, Jan Aberg, Damon E. Turney,
+#'and Scott D. Miller. \emph{Buoyancy flux, turbulence, and the gas transfer
 #'coefficient in a stratified lake}. Geophysical Research Letters 37, no. 24 (2010).
 #'
-#'Read, Jordan S., David P. Hamilton, Ankur R. Desai, Kevin C. Rose, Sally MacIntyre, 
-#'John D. Lenters, Robyn L. Smyth et al. \emph{Lake-size dependency of wind shear and convection 
+#'Read, Jordan S., David P. Hamilton, Ankur R. Desai, Kevin C. Rose, Sally MacIntyre,
+#'John D. Lenters, Robyn L. Smyth et al. \emph{Lake-size dependency of wind shear and convection
 #'as controls on gas exchange}. Geophysical Research Letters 39, no. 9 (2012).
 #'
-#'Crusius, John, and Rik Wanninkhof. \emph{Gas transfer velocities measured at low 
+#'Crusius, John, and Rik Wanninkhof. \emph{Gas transfer velocities measured at low
 #'wind speed over a lake}. Limnology and Oceanography 48, no. 3 (2003): 1010-1017.
 #'
-#'Dominic Vachon and Yves T. Prairie. \emph{The ecosystem size and shape dependence 
+#'Dominic Vachon and Yves T. Prairie. \emph{The ecosystem size and shape dependence
 #'of gas transfer velocity versus wind speed relationships in lakes}.
 #'Can. J. Fish. Aquat. Sci. 70 (2013): 1757-1764.
 #'
@@ -72,24 +72,24 @@
 #'
 #'@author
 #'Hilary Dugan, Jake Zwart, Luke Winslow, R. Iestyn. Woolway, Jordan S. Read
-#'@seealso 
+#'@seealso
 #'\link{k.cole}
 #'\link{k.crusius}
 #'\link{k.macIntyre}
 #'\link{k.vachon}
 #'\link{k.heiskanen}
-#'@examples 
+#'@examples
 #'data.path = system.file('extdata', package="LakeMetabolizer")
 #'
 #'tb.data = load.all.data('sparkling', data.path)
 #'
 #'ts.data = tb.data$data #pull out just the timeseries data
 #'
-#'#calculate U10 and add it back onto the original 
+#'#calculate U10 and add it back onto the original
 #'
 #'u10 = wind.scale(ts.data)
 #'ts.data = rmv.vars(ts.data, 'wnd', ignore.offset=TRUE) #drop old wind speed column
-#'ts.data = merge(ts.data, u10)                          #merge new u10 into big dataset  
+#'ts.data = merge(ts.data, u10)                          #merge new u10 into big dataset
 #'
 #'
 #'k600_cole = k.cole(ts.data)
@@ -102,75 +102,75 @@
 #'lat       = tb.data$metadata$latitude
 #'lake.area = tb.data$metadata$lakearea
 #'
-#'#for k.read and k.macIntyre, we need LW_net. 
-#'#Calculate from the observations we have available. 
+#'#for k.read and k.macIntyre, we need LW_net.
+#'#Calculate from the observations we have available.
 #'
 #'lwnet = calc.lw.net(ts.data, lat, atm.press)
 #'ts.data = merge(ts.data, lwnet)
-#'\dontrun{
-#'k600_read = k.read(ts.data, wnd.z=wnd.z, Kd=kd, atm.press=atm.press, 
+#'
+#'k600_read = k.read(ts.data, wnd.z=wnd.z, Kd=kd, atm.press=atm.press,
 #'	lat=lat, lake.area=lake.area)
 #'
-#'k600_soloviev = k.read.soloviev(ts.data, wnd.z=wnd.z, Kd=kd, 
+#'k600_soloviev = k.read.soloviev(ts.data, wnd.z=wnd.z, Kd=kd,
 #'	atm.press=atm.press, lat=lat, lake.area=lake.area)
 #'
 #'k600_macIntyre = k.macIntyre(ts.data, wnd.z=wnd.z, Kd=kd, atm.press=atm.press)
-#'}
+#'
 #'@export
 k.read = function(ts.data, wnd.z, Kd, atm.press, lat, lake.area){
-  
+
   S_B <- 5.67E-8 # Stefan-Boltzman constant (K is used)
   emiss <- 0.972 # emissivity;
   Kelvin = 273.15 #conversion from C to Kelvin
-  
+
   data = ts.data
-  # Get short wave radiation data 
-  if(has.vars(data, 'sw')){ 
+  # Get short wave radiation data
+  if(has.vars(data, 'sw')){
     sw <- get.vars(data, 'sw')
-    
+
   } else if (has.vars(data, 'par')){
     tmp.par = get.vars(data, 'par')
     sw = par.to.sw(tmp.par)
-  } else {  
+  } else {
     stop("Data must have PAR or SW column\n")
   }
-  
+
   wtr <- get.vars(data,'wtr')
   Ts <- get.Ts(data)
 
   airT <- get.vars(data, 'airt')
-  
+
   RH <- get.vars(data, 'rh')
-  
+
   # Get long wave radiation data
-  if(has.vars(data, 'lwnet')){ 
+  if(has.vars(data, 'lwnet')){
     lwnet <- get.vars(data,'lwnet')
-    
+
   } else if(has.vars(data, 'lw')){
     lw_in <- get.vars(data, 'lw') # long wave in
     Tk <- Ts+Kelvin # water temperature in Kelvin
     LWo <- S_B*emiss*Tk^4 # long wave out
     lwnet <- lw_in[,2]-LWo
-    
+
     lwnet = data.frame(datetime=lw_in$datetime, lwnet=lwnet)
-    
-  } else {  
+
+  } else {
     stop("no longwave radiation available")
   }
-  
+
 
   wnd <- get.vars(data, 'wnd')
-  
+
   m.d = ts.meta.depths(wtr)
-  
-  k600 = k.read.base(wnd.z, Kd, lat, lake.area, atm.press, data$datetime, Ts[,2], m.d$top, 
+
+  k600 = k.read.base(wnd.z, Kd, lat, lake.area, atm.press, data$datetime, Ts[,2], m.d$top,
                 airT[,2], wnd[,2], RH[,2], sw[,2], lwnet[,2])
-  
+
   return(data.frame(datetime=data$datetime, k600=k600))
 }
 
 #'@name k.read.base
-#'@aliases 
+#'@aliases
 #'k.read.base
 #'k.read.soloviev.base
 #'k.cole.base
@@ -179,20 +179,20 @@ k.read = function(ts.data, wnd.z, Kd, atm.press, lat, lake.area){
 #'k.vachon.base
 #'k.heiskanen.base
 #'@title Returns a timeseries of gas exchange velocity
-#'@description 
+#'@description
 #'Returns the gas exchange velocity based on the chosen model in units of m/day
 #'@usage
 #'k.cole.base(wnd)
 #'
 #'k.crusius.base(wnd, method='power')
 #'
-#'k.read.base(wnd.z, Kd, lat, lake.area, atm.press, dateTime, Ts, z.aml, 
+#'k.read.base(wnd.z, Kd, lat, lake.area, atm.press, dateTime, Ts, z.aml,
 #'airT, wnd, RH, sw, lwnet)
 #'
-#'k.read.soloviev.base(wnd.z, Kd, lat, lake.area, atm.press, dateTime, Ts, z.aml, 
+#'k.read.soloviev.base(wnd.z, Kd, lat, lake.area, atm.press, dateTime, Ts, z.aml,
 #'airT, wnd, RH, sw, lwnet)
 #'
-#'k.macIntyre.base(wnd.z, Kd, atm.press, dateTime, Ts, z.aml, airT, wnd, RH, sw, 
+#'k.macIntyre.base(wnd.z, Kd, atm.press, dateTime, Ts, z.aml, airT, wnd, RH, sw,
 #'lwnet, params=c(1.2,0.4872,1.4784))
 #'
 #'k.vachon.base(wnd, lake.area, params=c(2.51,1.48,0.39))
@@ -214,29 +214,29 @@ k.read = function(ts.data, wnd.z, Kd, atm.press, lat, lake.area){
 #'@param sw Numeric value of short wave radiation, W m^-2
 #'@param lwnet Numeric value net long wave radiation, W m^-2
 #'@param params Optional parameter input, only for \link{k.vachon.base} and \link{k.macIntyre.base}. See details.
-#'@details Can change default parameters of MacIntyre and Vachon models. Default for Vachon is 
-#'c(2.51,1.48,0.39). Default for MacIntyre is c(1.2,0.4872,1.4784). Heiskanen et al. (2014) uses MacIntyre 
+#'@details Can change default parameters of MacIntyre and Vachon models. Default for Vachon is
+#'c(2.51,1.48,0.39). Default for MacIntyre is c(1.2,0.4872,1.4784). Heiskanen et al. (2014) uses MacIntyre
 #'model with c(0.5,0.77,0.3) and z.aml constant at 0.15.
-#'@return Numeric value of gas exchange velocity (k600) in units of m/day. Before use, 
+#'@return Numeric value of gas exchange velocity (k600) in units of m/day. Before use,
 #'should be converted to appropriate gas using \link{k600.2.kGAS}.
 #'@keywords methods math
 #'@references
-#'Cole, J., J. Nina, and F. Caraco. \emph{Atmospheric exchange of carbon dioxide 
-#'in a low-wind oligotrophic lake measured by the addition of SF~ 6}. 
+#'Cole, J., J. Nina, and F. Caraco. \emph{Atmospheric exchange of carbon dioxide
+#'in a low-wind oligotrophic lake measured by the addition of SF~ 6}.
 #'Limnology and Oceanography 43 (1998): 647-656.
 #'
-#'MacIntyre, Sally, Anders Jonsson, Mats Jansson, Jan Aberg, Damon E. Turney, 
-#'and Scott D. Miller. \emph{Buoyancy flux, turbulence, and the gas transfer 
+#'MacIntyre, Sally, Anders Jonsson, Mats Jansson, Jan Aberg, Damon E. Turney,
+#'and Scott D. Miller. \emph{Buoyancy flux, turbulence, and the gas transfer
 #'coefficient in a stratified lake}. Geophysical Research Letters 37, no. 24 (2010).
 #'
-#'Read, Jordan S., David P. Hamilton, Ankur R. Desai, Kevin C. Rose, Sally MacIntyre, 
-#'John D. Lenters, Robyn L. Smyth et al. \emph{Lake-size dependency of wind shear and convection 
+#'Read, Jordan S., David P. Hamilton, Ankur R. Desai, Kevin C. Rose, Sally MacIntyre,
+#'John D. Lenters, Robyn L. Smyth et al. \emph{Lake-size dependency of wind shear and convection
 #'as controls on gas exchange}. Geophysical Research Letters 39, no. 9 (2012).
 #'
-#'Crusius, John, and Rik Wanninkhof. \emph{Gas transfer velocities measured at low 
+#'Crusius, John, and Rik Wanninkhof. \emph{Gas transfer velocities measured at low
 #'wind speed over a lake}. Limnology and Oceanography 48, no. 3 (2003): 1010-1017.
 #'
-#'Dominic Vachon and Yves T. Prairie. \emph{The ecosystem size and shape dependence 
+#'Dominic Vachon and Yves T. Prairie. \emph{The ecosystem size and shape dependence
 #'of gas transfer velocity versus wind speed relationships in lakes}.
 #'Can. J. Fish. Aquat. Sci. 70 (2013): 1757-1764.
 #'
@@ -250,18 +250,18 @@ k.read = function(ts.data, wnd.z, Kd, atm.press, lat, lake.area){
 #'
 #'@author
 #'R. Iestyn. Woolway, Hilary Dugan, Luke Winslow, Jordan S Read, GLEON fellows
-#'@seealso 
+#'@seealso
 #'\link{k.cole}
 #'\link{k.read}
 #'\link{k.crusius}
 #'\link{k.macIntyre}
 #'\link{k.vachon}
 #'\link{k.heiskanen}
-#'@examples 
+#'@examples
 #'wnd.z <- 2
 #'Kd <- 2
 #'lat <- 54
-#'lake.area <- 5000 
+#'lake.area <- 5000
 #'atm.press <- 1013
 #'dateTime <- as.POSIXct("2013-12-30 14:00")
 #'Ts <- 16.5
@@ -279,20 +279,20 @@ k.read = function(ts.data, wnd.z, Kd, atm.press, lat, lake.area){
 #'
 #'k600_crusius <- k.crusius.base(U10)
 #'
-#'k600_read <- k.read.base(wnd.z, Kd, lat, lake.area, atm.press, 
+#'k600_read <- k.read.base(wnd.z, Kd, lat, lake.area, atm.press,
 #'dateTime, Ts, z.aml, airT, wnd, RH, sw, lwnet)
 #'
-#'k600_soloviev <- k.read.soloviev.base(wnd.z, Kd, lat, lake.area, 
+#'k600_soloviev <- k.read.soloviev.base(wnd.z, Kd, lat, lake.area,
 #'atm.press, dateTime, Ts, z.aml, airT, wnd, RH, sw, lwnet)
 #'
-#'k600_macInytre <- k.macIntyre.base(wnd.z, Kd, atm.press, 
+#'k600_macInytre <- k.macIntyre.base(wnd.z, Kd, atm.press,
 #'dateTime, Ts, z.aml, airT, wnd, RH, sw, lwnet)
 #'
 #'@export
-k.read.base <- function(wnd.z, Kd, lat, lake.area, atm.press, dateTime, Ts, z.aml, airT, wnd, RH, sw, lwnet){ 
-  
+k.read.base <- function(wnd.z, Kd, lat, lake.area, atm.press, dateTime, Ts, z.aml, airT, wnd, RH, sw, lwnet){
+
   # define constants used in function
-  Kelvin <- 273.15 # temp mod for deg K   
+  Kelvin <- 273.15 # temp mod for deg K
   emiss <- 0.972 # emissivity;
   S_B <- 5.67E-8 # Stefan-Boltzman constant (?K is used)
   vonK <- 0.41 # von Karman  constant
@@ -305,24 +305,24 @@ k.read.base <- function(wnd.z, Kd, lat, lake.area, atm.press, dateTime, Ts, z.am
   g <- 9.81 # gravity
   C_w <- 4186 # J kg-1 ?C-1 (Lenters et al. 2005)
   mnWnd <- 0.2 # minimum wind speed
-  
+
   # impose limit on wind speed
   rpcI <- wnd < mnWnd
   wnd[rpcI] <- mnWnd
-  
+
   # calculate sensible and latent heat fluxes
   mm <- calc.zeng(dateTime,Ts,airT,wnd,RH,atm.press,wnd.z)
   C_D <- mm$C_D # drag coefficient for momentum
   E <- mm$alh # latent heat flux
   H <- mm$ash # sensible heat flux
-  
+
   # calculate total heat flux
   dUdt <- sw*0.93 - E - H + lwnet
   Qo <- sw*(1-albedo_SW)*swRat
-  
+
   # calculate water density
   rho_w <- water.density(Ts)
-  
+
   # calculate u*
   if (wnd.z != 10) {
     e1 <- sqrt(C_D)
@@ -331,17 +331,17 @@ k.read.base <- function(wnd.z, Kd, lat, lake.area, atm.press, dateTime, Ts, z.am
   rhoAir <- 1.2 #  air density
   tau <- C_D*wnd^2*rhoAir
   uSt <- sqrt(tau/rho_w)
-  
+
   # calculate the effective heat flux
   q1 <- 2-2*exp(z.aml*-Kd)
   q2 <- z.aml*Kd
   q3 <- exp(z.aml*-Kd)
   H_star <- dUdt-Qo*(q1/q2-q3) # Kim 1976
-  
-  # calculate the thermal expansion coefficient 
-  thermalExpFromTemp <- function(Ts) {    
-    V <- 1       
-    dT <- 0.001 
+
+  # calculate the thermal expansion coefficient
+  thermalExpFromTemp <- function(Ts) {
+    V <- 1
+    dT <- 0.001
     T1 <- water.density(Ts)
     T2 <- water.density(Ts+dT)
     V2 <- T1/T2
@@ -350,7 +350,7 @@ k.read.base <- function(wnd.z, Kd, lat, lake.area, atm.press, dateTime, Ts, z.am
     return (alpha)
   }
   tExp <- thermalExpFromTemp(Ts)
-  
+
   # calculate buoyancy flux and w*
   B1 <- H_star*tExp*g
   B2 <- rho_w*C_w
@@ -361,7 +361,7 @@ k.read.base <- function(wnd.z, Kd, lat, lake.area, atm.press, dateTime, Ts, z.am
   divi <- 1/3
   w1 <- -B1*z.aml
   wSt <- w1^divi
-  
+
   # calculate kinematic viscosiy
   getKinematicVis <- function(Ts) {
     # from Mays 2005, Water Resources Engineering
@@ -370,21 +370,21 @@ k.read.base <- function(wnd.z, Kd, lat, lake.area, atm.press, dateTime, Ts, z.am
     visTable <- c(1.792,1.519,1.308,1.141,1.007,0.897,
                   0.804,0.727,0.661,0.605,0.556,0.513,0.477,0.444,
                   0.415,0.39,0.367,0.347,0.328,0.311,0.296)
-    v <- data.frame(approx(tempTable,visTable,xout = Ts))[2]
+    v <- approx(tempTable,visTable,xout = Ts)$y
     v <- v*1e-6
     return(v)
   }
   kinV <- getKinematicVis(Ts)
-  
+
   KeDe <- (kinV*g)
   KeNm <- uSt^3
   Ke <- KeNm/KeDe
   tau <- tau    # estimate of total tau (includes wave stress)
   euPw <- (1+Ke/KeCrit)  # tau_shear = tau/(1+Ke/Kecr)
   tau_t <- tau/euPw      # tau_shear, Soloviev
-  uTanS <- tau_t/rho_w   
+  uTanS <- tau_t/rho_w
   uTanS <- uTanS^0.5
-  
+
   # calculate viscous sublayer
   Sv <- C1*kinV/uTanS
   eu_N <- uTanS^3      # e_u(0) = (tau_t/rho)^1.5/(vonK*Sv)
@@ -397,7 +397,7 @@ k.read.base <- function(wnd.z, Kd, lat, lake.area, atm.press, dateTime, Ts, z.am
   K1 <- K1*100^4*3600^4 # now in cm4/hr4  (Total)
   K2 <- K2*100^4*3600^4 # now in cm4/hr4  (Convective)
   K600 <- nu*600^(-0.5)*K1^(1/4)   # in cm/hr (Total)
-  
+
   k600 <- as.numeric(K600)
   k600 <- k600*24/100 #now in units in m d-1
   return(k600)
